@@ -444,7 +444,7 @@ void blank_anchors(int32_t sy,int32_t sx,int32_t ey,int32_t ex) {
 	}
 
 widget::widget() {
-	visibility_flags=WIDGET_VISIBILITY_ACTUALLY_VISIBLE|WIDGET_VISIBILITY_CAN_KEY_ACTIVATE;
+	flag=WIDGET_VISIBILITY_ACTUALLY_VISIBLE|WIDGET_CAN_KEY_ACTIVATE;
 	name = "";
 	tooltip="";
 	tooltip_type=TooltipType::NONE;
@@ -456,13 +456,23 @@ widget::widget() {
 void widget::move_to_anchor() {
 	// for the opinionated: the parens are for clarity, it changes no semantics, i know this
 	extentst parent_rect;
-	if (parent)
+	if (!(flag&WIDGET_GLOBAL_POSITIONING))
 		{
-		parent_rect=parent->get_rect();
+		if (parent)
+			{
+			parent_rect=parent->get_rect();
+			}
+		else
+			{
+			parent_rect=gview.grab_lastscreen()->get_rect();
+			}
 		}
 	else
 		{
-		parent_rect=gview.grab_lastscreen()->get_rect();
+		parent_rect.sx=0;
+		parent_rect.sy=0;
+		parent_rect.ex=::init.display.grid_x;
+		parent_rect.ey=::init.display.grid_y;
 		}
     rect.sx=parent_rect.sx+((parent_rect.ex-parent_rect.sx)*anchor_left)+offset_left;
 	rect.ex=parent_rect.sx+((parent_rect.ex-parent_rect.sx)*anchor_right)+offset_right;
@@ -912,18 +922,18 @@ widget::~widget()
 	}
 
 bool widget::can_key_activate() {
-	return !!(visibility_flags & WIDGET_VISIBILITY_CAN_KEY_ACTIVATE);
+	return !!(flag & WIDGET_CAN_KEY_ACTIVATE);
 	}
 
 bool widget::set_can_key_activate(bool can, bool children_too) {
 	const auto old=can_key_activate();
 	if (can)
 		{
-		visibility_flags|=WIDGET_VISIBILITY_CAN_KEY_ACTIVATE;
+		flag|=WIDGET_CAN_KEY_ACTIVATE;
 		}
 	else
 		{
-		visibility_flags&=~WIDGET_VISIBILITY_CAN_KEY_ACTIVATE;
+		flag&=~WIDGET_CAN_KEY_ACTIVATE;
 		}
 	if (children_too)
 		{
@@ -993,6 +1003,7 @@ void widget::render(uint32_t curtick)
 					c->add_widget<widgets::text>("Hotkey: ");
 					c->add_widget<widgets::keybinding_display>(key);
 					}
+				tooltip_widget->set_global_positioning(false); // want this by default...
 				switch (tooltip_type)
 					{
 					case TooltipType::ABOVE:
@@ -1014,8 +1025,8 @@ void widget::render(uint32_t curtick)
 						//upper right
 						//*************************** TEXTURE SIZE DEPENDENCE
 						tooltip_widget->set_anchors_preset(LayoutPreset::TOP_RIGHT);
-						tooltip_widget->set_parent(gview.grab_lastscreen());
-						tooltip_widget->set_offsets(-1,192/12+1,-192/8+1,1);
+						tooltip_widget->set_offsets(0,192/12+1,-192/8+1,0);
+						tooltip_widget->set_global_positioning(true); // but want it to be global for this, since minimap is
 						break;
 						}
 					}
@@ -1110,19 +1121,22 @@ bool widget::inside(int32_t y, int32_t x) {
     return is_visible() && x >= rect.sx && x <= rect.ex && y >= rect.sy && y <= rect.ey;
 }
 
+template<typename T>
+bool set_flag_ret_old(T &flag,T which_flag, bool set) {
+	bool prev=!!(flag&which_flag);
+	if (set) flag|=which_flag;
+	else flag&=~which_flag;
+	return prev;
+	}
+
 bool widget::set_active(bool n)
 	{
-	bool prev=!!(visibility_flags&WIDGET_VISIBILITY_ACTIVE);
-	if (n) visibility_flags|=WIDGET_VISIBILITY_ACTIVE;
-	else visibility_flags&=~WIDGET_VISIBILITY_ACTIVE;
-	return prev;
+	return set_flag_ret_old(flag,WIDGET_VISIBILITY_ACTIVE,n);
 	}
 
 bool widget::set_visible(bool n)
 	{
-	bool prev=!!(visibility_flags&WIDGET_VISIBILITY_VISIBLE);
-	if (n) visibility_flags|=WIDGET_VISIBILITY_VISIBLE;
-	else visibility_flags&=~WIDGET_VISIBILITY_VISIBLE;
+	auto prev=set_flag_ret_old(flag,WIDGET_VISIBILITY_VISIBLE,n);
 	// Not done for set_active on purpose!
 	if (auto c=dynamic_cast<container *>(this); c)
 		{
@@ -1134,6 +1148,10 @@ bool widget::set_visible(bool n)
 	return prev;
 	}
 
+bool widget::set_global_positioning(bool n) {
+	return set_flag_ret_old(flag,WIDGET_GLOBAL_POSITIONING,n);
+	}
+
 void widget::clear() {}
 
 
@@ -1471,7 +1489,7 @@ int container::visible_children()
 
 int container::active_children()
 	{
-	return std::count_if(children.begin(),children.end(),[](auto &c) { return !!(c->visibility_flags&WIDGET_VISIBILITY_ACTIVE); });
+	return std::count_if(children.begin(),children.end(),[](auto &c) { return !!(c->flag&WIDGET_VISIBILITY_ACTIVE); });
 	}
 
 void container::remove_child(const string &id)
@@ -1674,7 +1692,7 @@ void scroll_rows::scroll_to(int32_t idx) {
 
 bool widget_is_active(std::shared_ptr<widgets::widget> &w)
 	{
-	return !!(w->visibility_flags&WIDGET_VISIBILITY_ACTIVE);
+	return !!(w->flag&WIDGET_VISIBILITY_ACTIVE);
 	}
 
 void scroll_rows::arrange() {
@@ -1986,7 +2004,7 @@ void tabs::feed(set<InterfaceKey>& events) {
 			for (auto i=row.first; i<=row.second; ++i)
 				{
 				bool can_switch_to_tab=true;
-				if (i<children.size()&&!(children[i]->visibility_flags&WIDGET_VISIBILITY_ACTIVE))
+				if (i<children.size()&&!(children[i]->flag&WIDGET_VISIBILITY_ACTIVE))
 					{
 					can_switch_to_tab=false;
 					}
@@ -2065,7 +2083,7 @@ void tabs::render(uint32_t curtick) {
 			bool is_active=true;
 			if (i<children.size())
 				{
-				is_active=!!(children[i]->visibility_flags&WIDGET_VISIBILITY_ACTIVE);
+				is_active=!!(children[i]->flag&WIDGET_VISIBILITY_ACTIVE);
 				}
 
 				// labels
