@@ -215,14 +215,13 @@ namespace widgets {
     // widgets themselves should be using--"active" should be used for 
     // stuff like folders or filters that externally change whether such things
     // are visible
-    enum VisibilityFlag
-        {
-        WIDGET_VISIBILITY_ACTIVE=BIT1,
-        WIDGET_VISIBILITY_VISIBLE=BIT2,
-        WIDGET_VISIBILITY_ACTUALLY_VISIBLE=BIT1|BIT2,
-        WIDGET_VISIBILITY_CAN_KEY_ACTIVATE=BIT3
-        };
-    using VisibilityFlagType=int8_t;
+    using WidgetFlag=uint8_t;
+
+    constexpr WidgetFlag WIDGET_VISIBILITY_ACTIVE=BIT1;
+    constexpr WidgetFlag WIDGET_VISIBILITY_VISIBLE=BIT2;
+    constexpr WidgetFlag WIDGET_VISIBILITY_ACTUALLY_VISIBLE=WIDGET_VISIBILITY_ACTIVE|WIDGET_VISIBILITY_VISIBLE;
+    constexpr WidgetFlag WIDGET_CAN_KEY_ACTIVATE=BIT3;
+    constexpr WidgetFlag WIDGET_GLOBAL_POSITIONING=BIT4;
 
     enum struct Side : int8_t
         {
@@ -267,7 +266,7 @@ namespace widgets {
     public:
     public:
         string name;
-        VisibilityFlagType visibility_flags=0;
+        WidgetFlag flag=0;
         // I ripped most of this stuff off from Godot's Control
         // In general tried to make it work like https://docs.godotengine.org/en/stable/tutorials/ui/size_and_anchors.html
         // Mostly for my own benefit, haha
@@ -302,8 +301,9 @@ namespace widgets {
         bool inside(int32_t y, int32_t x);
         bool set_active(bool n);
         bool set_visible(bool n);
+        bool set_global_positioning(bool n);
         bool set_can_key_activate(bool n, bool children_too=true);
-        bool is_visible() { return (visibility_flags&WIDGET_VISIBILITY_ACTUALLY_VISIBLE)==WIDGET_VISIBILITY_ACTUALLY_VISIBLE; }
+        bool is_visible() { return (flag&WIDGET_VISIBILITY_ACTUALLY_VISIBLE)==WIDGET_VISIBILITY_ACTUALLY_VISIBLE; }
         void set_parent(abstract_interfacest* p) { parent = p; }
         void set_custom_feed(std::function<void(std::set<InterfaceKey>&,widget *)> f) { custom_feed.push_back(f); }
         void set_custom_logic(std::function<void(widget *)> f) { custom_logic.push_back(f); }
